@@ -38,7 +38,7 @@ class TestLVM(tc.TestGraphGeneration):
         tree = self.load_config_file('lvm_tree.yaml')
         graph = self.load_config_file('lvm_graph.yaml')
         parsed_graph = config_tree_to_graph(tree)
-        self.assertItemsEqual(parsed_graph, graph)
+        self.assertCountEqual(parsed_graph, graph)
 
     def test_lvm_invalid_config(self):
         # test some invalid config paths
@@ -55,8 +55,8 @@ class TestLVM(tc.TestGraphGeneration):
         bad_config = copy.deepcopy(lvm_config)
         bad_config['lvs'][0]['base'] = ['invalid_vg']
         self.assertRaisesRegex(BlockDeviceSetupException,
-                               "base:\['invalid_vg'\] in lvs does not match "
-                               "a valid vg",
+                               r"base:\['invalid_vg'\] in lvs does not match "
+                               r"a valid vg",
                                LVMPlugin, bad_config, {}, {})
 
         bad_config = copy.deepcopy(lvm_config)
@@ -104,12 +104,18 @@ class TestLVM(tc.TestGraphGeneration):
             mock.call(['vgcreate', 'vg',
                        '/dev/fake/root', '/dev/fake/data', '--force']),
             # create a bunch of lv's on vg
-            mock.call(['lvcreate', '--name', 'lv_root', '-L', '1800M', 'vg']),
-            mock.call(['lvcreate', '--name', 'lv_tmp', '-L', '100M', 'vg']),
-            mock.call(['lvcreate', '--name', 'lv_var', '-L', '500M', 'vg']),
-            mock.call(['lvcreate', '--name', 'lv_log', '-L', '100M', 'vg']),
-            mock.call(['lvcreate', '--name', 'lv_audit', '-L', '100M', 'vg']),
-            mock.call(['lvcreate', '--name', 'lv_home', '-L', '200M', 'vg'])]
+            mock.call(['lvcreate', '--name', 'lv_root', '-L', '1799356416B',
+                       'vg']),
+            mock.call(['lvcreate', '--name', 'lv_tmp', '-L', '96468992B',
+                       'vg']),
+            mock.call(['lvcreate', '--name', 'lv_var', '-L', '499122176B',
+                       'vg']),
+            mock.call(['lvcreate', '--name', 'lv_log', '-L', '96468992B',
+                       'vg']),
+            mock.call(['lvcreate', '--name', 'lv_audit', '-L', '96468992B',
+                       'vg']),
+            mock.call(['lvcreate', '--name', 'lv_home', '-L', '197132288B',
+                       'vg'])]
 
         self.assertEqual(mock_exec_sudo.call_count, len(cmd_sequence))
         mock_exec_sudo.assert_has_calls(cmd_sequence)
@@ -216,17 +222,17 @@ class TestLVM(tc.TestGraphGeneration):
                            '/dev/fake/data', '--force']),
                 # create a bunch of lv's on vg
                 mock.call(['lvcreate', '--name', 'lv_root',
-                           '-L', '1800M', 'vg1']),
+                           '-L', '1799356416B', 'vg1']),
                 mock.call(['lvcreate', '--name', 'lv_tmp',
-                           '-L', '100M', 'vg1']),
+                           '-L', '96468992B', 'vg1']),
                 mock.call(['lvcreate', '--name', 'lv_var',
-                           '-L', '500M', 'vg2']),
+                           '-L', '499122176B', 'vg2']),
                 mock.call(['lvcreate', '--name', 'lv_log',
-                           '-L', '100M', 'vg2']),
+                           '-L', '96468992B', 'vg2']),
                 mock.call(['lvcreate', '--name', 'lv_audit',
-                           '-L', '100M', 'vg2']),
+                           '-L', '96468992B', 'vg2']),
                 mock.call(['lvcreate', '--name', 'lv_home',
-                           '-L', '200M', 'vg2'])]
+                           '-L', '197132288B', 'vg2'])]
 
             self.assertListEqual(mock_exec_sudo.call_args_list,
                                  cmd_sequence)
@@ -389,9 +395,9 @@ class TestLVM(tc.TestGraphGeneration):
                            '/dev/fake/data1', '/dev/fake/data2', '--force']),
                 # create root and data volume
                 mock.call(['lvcreate', '--name', 'lv_root',
-                           '-L', '1800M', 'vg_root']),
+                           '-L', '1799356416B', 'vg_root']),
                 mock.call(['lvcreate', '--name', 'lv_data',
-                           '-L', '2G', 'vg_data'])
+                           '-L', '1996488704B', 'vg_data'])
             ]
 
             self.assertListEqual(mock_exec_sudo.call_args_list,
@@ -512,7 +518,7 @@ class TestLVM(tc.TestGraphGeneration):
                 mock.call.create_mbr(),
                 # now mount partitions
                 mock.call.sudo_part(['sync']),
-                mock.call.sudo_part(['kpartx', '-avs', '/dev/fake/image0']),
+                mock.call.sudo_part(['kpartx', '-uvs', '/dev/fake/image0']),
                 # now create lvm environment
                 mock.call.sudo_lvm(['pvcreate', '/dev/fake/root', '--force']),
                 mock.call.sudo_lvm(
